pub async fn create_subscription(
    configuration: &Configuration,
    notification_type: &str,
    body: CreateSubscriptionRequest
) -> Result<CreateSubscriptionResponse, Error>
Creates a subscription for the specified notification type to be delivered to the specified destination. Before you can subscribe, you must first create the destination by calling the createDestination operation. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 5 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values than those shown here. For more information, see Usage Plans and Rate Limits in the Selling Partner API.