pub async fn delete_destination(
    configuration: &Configuration,
    destination_id: &str
) -> Result<DeleteDestinationResponse, Error>
Deletes the destination that you specify. The deleteDestination API is grantless. For more information, see Grantless operations in the Selling Partner API Developer Guide. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 5 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values than those shown here. For more information, see Usage Plans and Rate Limits in the Selling Partner API.