Function amazon_sp_notifications::apis::notifications_api::get_destinations
source · [−]pub async fn get_destinations(
configuration: &Configuration
) -> Result<GetDestinationsResponse, Error>Expand description
Returns information about all destinations. The getDestinations API is grantless. For more information, see Grantless operations in the Selling Partner API Developer Guide. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 5 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values than those shown here. For more information, see Usage Plans and Rate Limits in the Selling Partner API.