pub async fn get_subscription(
    configuration: &Configuration,
    notification_type: &str
) -> Result<GetSubscriptionResponse, Error>
Returns information about subscriptions of the specified notification type. You can use this API to get subscription information when you do not have a subscription identifier. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 5 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values than those shown here. For more information, see Usage Plans and Rate Limits in the Selling Partner API.